import * as echarts from 'echarts'

export function stackRightOptions(xAxisData, yAxisData) {
  return {
    tooltip: {},
    xAxis: {
      data: xAxisData,
      axisTick: { show: false },
      splitLine: { show: false },
      splitArea: { show: false }
    },
    yAxis: {
      axisTick: { show: false },
      splitLine: { show: false },
      splitArea: { show: false }
    },
    grid: {
      top: 10,
      bottom: 20
    },
    series: [
      {
        name: 'bar',
        type: 'bar',
        stack: 'one',
        data: yAxisData.data1,
        barWidth: 8,
        itemStyle: {
          normal: {
            color: '#00479D'
          }
        }
      },
      {
        name: 'bar2',
        type: 'bar',
        stack: 'one',
        data: yAxisData.data2,
        barWidth: 8,
        itemStyle: {
          normal: {
            color: '#EA68A2'
          }
        }
      },
      {
        name: 'bar3',
        type: 'bar',
        stack: 'one',
        data: yAxisData.data3,
        barWidth: 8,
        itemStyle: {
          normal: {
            color: '#00B7EE'
          }
        }
      },
      {
        name: 'bar4',
        type: 'bar',
        stack: 'one',
        data: yAxisData.data4,
        barWidth: 8,
        itemStyle: {
          normal: {
            color: '#18CC54'
          }
        }
      },
      {
        name: 'bar5',
        type: 'bar',
        stack: 'one',
        data: yAxisData.data4,
        barWidth: 8,
        itemStyle: {
          normal: {
            color: '#FFF34D'
          }
        }
      },
      {
        name: 'bar6',
        type: 'bar',
        stack: 'one',
        data: yAxisData.data4,
        barWidth: 8,
        itemStyle: {
          normal: {
            color: '#FF9500'
          }
        }
      }
    ]
  }
}

export function stackLeftOptions(xAxisData, yAxisData) {
  return {
    xAxis: [
      {
        type: 'category',
        data: ['2002', '2003', '2004', '2005', '2006', '2007', '2008'],
        axisPointer: {
          show: false
        },
        axisTick: { show: false },
        splitLine: { show: false },
        splitArea: { show: false }
      }
    ],
    grid: {
      top: 10,
      bottom: 20
    },
    yAxis: [
      {
        type: 'value',
        min: 0,
        max: 250,
        interval: 50
      },
      {
        type: 'value',
        min: 0,
        max: 25,
        interval: 5
      }
    ],
    series: [
      {
        name: 'Evaporation',
        type: 'bar',
        barWidth: 6,
        data: [2.0, 4.9, 7.0, 23.2, 25.6, 76.7, 135.6, 162.2, 32.6, 20.0, 6.4, 3.3],
        itemStyle: {
          color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
            {
              offset: 0,
              color: '#0080FF'
            },
            {
              offset: 1,
              color: 'rgba(0,128,255,0)'
            }
          ])
        }
      },
      {
        name: 'Precipitation',
        type: 'bar',
        barWidth: 6,
        data: [2.6, 5.9, 9.0, 26.4, 28.7, 70.7, 175.6, 182.2, 48.7, 18.8, 6.0, 2.3],
        itemStyle: {
          color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
            {
              offset: 0,
              color: '#00D5FF'
            },
            {
              offset: 1,
              color: 'rgba(0,195,255,0)'
            }
          ])
        }
      },
      {
        name: 'Temperature',
        type: 'line',
        smooth: true,
        yAxisIndex: 1,
        showSymbol: false,
        data: [2.0, 2.2, 3.3, 4.5, 6.3, 10.2, 20.3, 23.4, 23.0, 16.5, 12.0, 6.2],
        lineStyle: {
          color: '#FFD400',
          width: 1
        },
        areaStyle: {
          opacity: 0.8,
          color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
            {
              offset: 0,
              color: '#FFD400'
            },
            {
              offset: 1,
              color: 'rgba(255,212,0,0)'
            }
          ])
        }
      }
    ]
  }
}
